HttpRequestData class

Constructors

HttpRequestData(BaseRequest? requestOptions)

Properties

hashCode int
The hash code for this object.
no setterinherited
requestOptions → BaseRequest?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

redact(Map<String, dynamic> map, RedactionService redactor, {Set<String>? ignoredValues, Set<String>? ignoredKeys}) → void